FlutterCluster class

Constructors

FlutterCluster()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dbscan(List<LatLng> points, double eps, int minPoints) → List<List<LatLng>>
DBSCAN clustering algorithm. Returns a list of clusters, where each cluster is a list of LatLng points.
hdbscan(List<LatLng> points, double eps, int minPoints) → List<List<LatLng>>
HDBSCAN clustering algorithm. (Currently a stub implementation that calls DBSCAN.)
optics(List<LatLng> points, double eps, int minPoints) → List<List<LatLng>>
OPTICS clustering algorithm. (Currently a stub implementation that calls DBSCAN.)