KMeans class

Constructors

KMeans({required int k, int maxIterations = 100, double tolerance = 1e-4})

Properties

hashCode → int
The hash code for this object.
no setterinherited
k → int
final
maxIterations → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tolerance → double
final

Methods

cluster(List<LatLng> points) → List<List<LatLng>>
Clusters points into k clusters. Returns a list of clusters, where each cluster is a list of LatLng points.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

distance → const Distance