OPTICS class

Constructors

OPTICS(double epsilon, int minPts)

Properties

epsilon → double
final
hashCode → int
The hash code for this object.
no setterinherited
minPts → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optics(List<LatLng> points) → List<LatLng>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

distance → const Distance